@@ -316,7 +316,17 @@ class GitlabProjects
 
     if wait_for_pushes
       $logger.info "Syncing project #{@project_name} from <#{full_path}> to <#{new_full_path}>."
-      system(*%W(rsync -a --delete #{source_path} #{new_full_path}))
+
+      # Set a low IO priority with ionice to not choke the server on moves
+      rsync_path = 'ionice -c2 -n7 rsync'
+      result = system(*%W(#{rsync_path} -a --delete --rsync-path="#{rsync_path}" #{source_path} #{new_full_path}))
+
+      unless result
+        # If the command fails with `ionice` (maybe because we're on a OS X
+        # development machine), try again without `ionice`.
+        rsync_path = 'rsync'
+        system(*%W(#{rsync_path} -a --delete --rsync-path="#{rsync_path}" #{source_path} #{new_full_path}))
+      end
     else
       $logger.error "mv-storage failed: source path <#{full_path}> is waiting for pushes to finish."
       false
